@@ -178,9 +178,10 @@ describe 'gnocchi::api' do
       end
 
       let(:platform_params) do
-        if facts[:operatingsystem] == 'Ubuntu' then
-          package_name = 'python-gnocchi'
-        else
+        case facts[:osfamily]
+        when 'Debian'
+          package_name = 'gnocchi-api'
+        when 'RedHat'
           package_name = 'gnocchi-api'
         end
         { :api_package_name => package_name,
