@@ -9,12 +9,13 @@ describe 'gnocchi::logging' do
 
   let :log_params do
     {
-     :use_syslog => true,
-     :use_json => true,
-     :use_stderr => false,
+     :use_syslog   => true,
+     :use_json     => true,
+     :use_journal  => true,
+     :use_stderr   => false,
      :log_facility => 'LOG_FOO',
-     :log_dir => '/var/log',
-     :debug => true,
+     :log_dir      => '/var/log',
+     :debug        => true,
     }
   end
 
@@ -36,6 +37,7 @@ describe 'gnocchi::logging' do
       is_expected.to contain_oslo__log('gnocchi_config').with(
         :use_syslog          => '<SERVICE DEFAULT>',
         :use_json            => '<SERVICE DEFAULT>',
+        :use_journal         => '<SERVICE DEFAULT>',
         :use_stderr          => '<SERVICE DEFAULT>',
         :syslog_log_facility => '<SERVICE DEFAULT>',
         :log_dir             => '/var/log/gnocchi',
@@ -49,6 +51,7 @@ describe 'gnocchi::logging' do
       is_expected.to contain_oslo__log('gnocchi_config').with(
         :use_syslog          => true,
         :use_json            => true,
+        :use_journal         => true,
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
